Module: ShopsavvyDataApi
- Defined in:
- lib/shopsavvy_data_api.rb,
lib/shopsavvy_data_api/client.rb,
lib/shopsavvy_data_api/errors.rb,
lib/shopsavvy_data_api/models.rb,
lib/shopsavvy_data_api/version.rb
Overview
Official Ruby SDK for ShopSavvy Data API
This gem provides a convenient interface to interact with the ShopSavvy Data API, allowing you to access product data, pricing information, and price history across thousands of retailers and millions of products.
Defined Under Namespace
Classes: APIError, APIMeta, APIResponse, AuthenticationError, Client, Configuration, ConfigurationError, Deal, Error, NetworkError, NotFoundError, Offer, OfferWithHistory, PaginationInfo, PriceHistoryEntry, ProductDetails, ProductSearchResult, ProductWithOffers, RateLimitError, ScheduledProduct, TLDRReview, TimeoutError, UsageInfo, UsagePeriod, ValidationError
Constant Summary collapse
- VERSION =
"1.1.0"
Class Method Summary collapse
-
.new(api_key:, **options) ⇒ Client
Create a new ShopSavvy Data API client.
-
.with_config(config) ⇒ Client
Create a client with configuration object.